#define VRAYMTL_CLASS_ID Class_ID(0x37bf3f2f, 0x7034695c)

#define VRAYMTL_NSUBTEX 17

#define SUBTEXNO_DIFFUSE 0
#define SUBTEXNO_REFLECT 1
#define SUBTEXNO_REFRACT 2
#define SUBTEXNO_BUMP 3
#define SUBTEXNO_REFLECT_GLOSSINESS 4
#define SUBTEXNO_REFRACT_GLOSSINESS 5
#define SUBTEXNO_DISPLACEMENT 6
#define SUBTEXNO_ENVIRONMENT 7
#define SUBTEXNO_TRANSLUCENCY 8
#define SUBTEXNO_IOR 9
#define SUBTEXNO_HILIGHT_GLOSSINESS 10
#define SUBTEXNO_FRESNELIOR 11
#define SUBTEXNO_OPACITY 12
#define SUBTEXNO_ROUGHNESS 13
#define SUBTEXNO_ANISO 14
#define SUBTEXNO_ANISO_ROTATION 15
#define SUBTEXNO_FOG 16

namespace VRayMtlParameters {

// Parameter block IDs
enum {
	vrayMtl_old_id,
	vrayMtl_basic_id,
	vrayMtl_BRDF_id,
	vrayMtl_options_id,
	vrayMtl_maps_id,
	vrayMtl_reflIMap_id,
	vrayMtl_refrIMap_id,
};

// Parameters
enum {
	pb_spin,

	pb_diffuse_color,

	pb_reflect_color,
	pb_reflect_glossiness,
	pb_reflect_subdivs,

	pb_refract_color,
	pb_refract_glossiness,
	pb_refract_subdivs,

	pb_reflect_fresnel,
	pb_refract_ior,

	pb_brdf_type,

	pb_reflect_trace,
	pb_refract_trace,

	pb_doubleSided,
	pb_reflectOnBack,

	pb_diffuse_trace,
	pb_diffuse_subdivs,

	pb_useIrradMap,
	pb_diffuseGlossy,
	pb_traceCaustics,

	pb_reflect_maxDepth,
	pb_refract_maxDepth,
	pb_cutoffThresh,

	pb_refract_fogColor,
	pb_refract_fogMult,

	pb_refract_translucent,
	pb_refract_thickness,
	pb_refract_volSubdivs,
	pb_refract_lightMult_old,
	pb_refract_scatterCoeff,
	pb_refract_scatterDir,
	pb_refract_lightMult,

	pb_fog_affectShadows,

	pb_useInterpolation,
	pb_interpSamples,
	pb_colorThreshold,

	pb_preservationMode,
	pb_translucent_color,
	pb_translucent_map,

	pb_reflect_minRate,
	pb_reflect_maxRate,
	pb_reflect_clrThresh,
	pb_reflect_nrmThresh,
	pb_reflect_interpSamples,
	pb_reflect_preset,

	pb_refract_minRate,
	pb_refract_maxRate,
	pb_refract_clrThresh,
	pb_refract_nrmThresh,
	pb_refract_interpSamples,
	pb_refract_preset,

	pb_reflect_exitColor,
	pb_refract_exitColor,
	pb_refract_exitColor_on,

	pb_brdf_anisotropy,
	pb_brdf_anisotropy_channel,

	pb_reflect_useInterpolation,
	pb_refract_useInterpolation,

	pb_brdf_anisotropy_rotation,
	pb_brdf_anisotropy_derivation,
	pb_brdf_anisotropy_axis,

	pb_refract_affectAlpha,
	pb_hilight_glossiness,
	pb_reflect_ior,
	pb_reflect_glossiness_lock,
	pb_reflect_ior_lock,

	pb_refract_fogBias,

	pb_environment_priority,
	pb_diffuse_roughness,

	pb_brdf_soften,
	pb_clampColors,

	pb_reflect_dimDistance,
	pb_reflect_dimDistanceFallOff,
	pb_reflect_dimDistanceOn,

	pb_refract_dispersion,
	pb_refract_dispersionOn,

	pb_refract_fogUnitScaleOn,
	pb_brdf_fixDarkEdges,

	pb_effect_id,
	pb_override_effect_id,

	pb_reflect_affectAlpha,
};

#define SUBTEX_PARAM_ID 100
#define ON_OFFSET 50
#define MULT_OFFSET 100

#define VRAYMTL_TEXMAP_PARAMID(subtexNo) (SUBTEX_PARAM_ID+subtexNo)
#define VRAYMTL_TEXMAP_ON_PARAMID(subtexNo) (SUBTEX_PARAM_ID+subtexNo+ON_OFFSET)
#define VRAYMTL_TEXMAP_MULT_PARAMID(subtexNo) (SUBTEX_PARAM_ID+subtexNo+MULT_OFFSET)

} // namespace VRayMtlParameters

VRayPlugin *exportVRayMtlAsBRDF_old(TimeValue t, Mtl *mtl, const tchar *material_name, ExportFlags flags)
{
	Color diffuse_color(0.5, 0.5, 0.5);
	Color reflection_color(0.0, 0.0, 0.0);
	Color refraction_color(0.0, 0.0, 0.0);
	
	Texmap *diffuse_texture = NULL;
	float diffuse_mult = 1.0;
	
	Texmap *bump_texture = NULL;
	float bump_mult = 1.0;
	
	Texmap *reflection_texture = NULL;
	float reflection_mult=1.0;
	int reflection_trace = true;
	int reflection_depth = 5;
	float anisotropy=0.0f, anisotropy_rotation=0.0f;
	int anisotropy_derivation=0;
	int anisotropy_axis=2;
	int anisotropy_mapChannel=1;
	
	Texmap *refraction_texture = NULL;
	float refraction_mult = 1.0f;
	float refraction_ior = 1.6f;
	int refraction_affect_shadows = false;
	int refraction_trace = true;
	int refraction_depth = 5;
	
	int fresnel = false;
	float fresnel_ior = 1.6f;

	Color fog_color(1.0, 1.0, 1.0);
	float fog_mult = 1.0f;
	
	int option_reflect_on_back_side = false;
	float option_cutoff = 0.001f;
	option_doubleSided = true;
	
	int opacity_value = 1;
	Texmap *opacity_texture = NULL;
	float opacity_mult = 1.0f;
	
	Texmap *reflection_glossiness_texture = NULL;
	float reflection_glossiness_texture_mult = 1.0f;
	
	Texmap *hilight_glossiness_texture = NULL;
	float hilight_glossiness_texture_mult = 1.0f;

	Texmap *anisotropy_texture=NULL;
	float anisotropy_texture_mult = 1.0f;

	Texmap *anisotropy_rotation_texture=NULL;
	float anisotropy_rotation_texture_mult = 1.0f;

	int brdfType=1;

	Point3 pnt3;
	bool existing;
	
	IParamBlock2 *pblockBasic=vrayMtl->GetParamBlockByID(VRayMtlParameters::vrayMtl_basic_id);
	IParamBlock2 *pblockMaps=vrayMtl->GetParamBlockByID(VRayMtlParameters::vrayMtl_maps_id);
	IParamBlock2 *pblockOptions=vrayMtl->GetParamBlockByID(VRayMtlParameters::vrayMtl_options_id);
	IParamBlock2 *pblockBRDF=vrayMtl->GetParamBlockByID(VRayMtlParameters::vrayMtl_BRDF_id);

	diffuse_color = toColor(pblockBasic->GetColor(VRayMtlParameters::pb_diffuse_color, t));
	reflection_color = toColor(pblockBasic->GetColor(VRayMtlParameters::pb_reflect_color, t));
	refraction_color = toColor(pblockBasic->GetColor(VRayMtlParameters::pb_refract_color, t));

	fresnel = pblockBasic->GetInt(VRayMtlParameters::pb_reflect_fresnel, t);
	option_reflect_on_back_side = pblockOptions->GetInt(VRayMtlParameters::pb_reflectOnBack, t);
	fresnel_ior = pblockBasic->GetFloat(VRayMtlParameters::pb_reflect_ior, t);

	if (pblockBasic->GetInt(VRayMtlParameters::pb_reflect_ior_lock, t)) fresnel_ior = pblockBasic->GetFloat(VRayMtlParameters::pb_refract_ior, t);

	refraction_affect_shadows = pblockBasic->GetInt(VRayMtlParameters::pb_fog_affectShadows, t);
	refraction_ior = pblockBasic->GetFloat(VRayMtlParameters::pb_refract_ior); 

	fog_color = toColor(pblockBasic->GetColor(VRayMtlParameters::pb_refract_fogColor, t));
	fog_mult = pblockBasic->GetFloat(VRayMtlParameters::pb_refract_fogMult);

	reflection_trace=pblockOptions->GetInt(VRayMtlParameters::pb_reflect_trace);
	refraction_trace=pblockOptions->GetInt(VRayMtlParameters::pb_refract_trace);
	option_doubleSided=pblockOptions->GetInt(VRayMtlParameters::pb_doubleSided);
	option_cutoff = pblockOptions->GetFloat(VRayMtlParameters::pb_cutoffThresh);

	reflection_depth=pblockBasic->GetInt(VRayMtlParameters::pb_reflect_maxDepth);
	refraction_depth=pblockBasic->GetInt(VRayMtlParameters::pb_refract_maxDepth);

	anisotropy=pblockBRDF->GetFloat(VRayMtlParameters::pb_brdf_anisotropy, t);
	anisotropy_rotation=pblockBRDF->GetFloat(VRayMtlParameters::pb_brdf_anisotropy_rotation, t)/360.0f;
	anisotropy_derivation=pblockBRDF->GetInt(VRayMtlParameters::pb_brdf_anisotropy_derivation);
	anisotropy_axis=pblockBRDF->GetInt(VRayMtlParameters::pb_brdf_anisotropy_axis);
	anisotropy_mapChannel=pblockBRDF->GetInt(VRayMtlParameters::pb_brdf_anisotropy_channel);

	brdfType=pblockBRDF->GetInt(VRayMtlParameters::pb_brdf_type);

	if (vrayMtl->ClassID() == VRAYMTL_CLASS_ID)
	{
		// Textures
		int map_on;
		float map_mult;

		// Diffuse map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_DIFFUSE), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_DIFFUSE), t)/100.0f;
		if (map_on && map_mult > 0.0) {
			diffuse_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_DIFFUSE));
			diffuse_mult = map_mult;
		}

		// bump map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_BUMP), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_BUMP), t)/100.0f;
		if (map_on && map_mult != 0.0)
		{
			bump_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_BUMP));
			bump_mult = map_mult;
		}

		// reflection map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_REFLECT), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_REFLECT), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			reflection_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_REFLECT));
			reflection_mult = map_mult;
		}

		// refraction map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_REFRACT), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_REFRACT), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			refraction_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_REFRACT));
			refraction_mult = map_mult;
		}

		// opacity map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_OPACITY), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_OPACITY), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			opacity_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_OPACITY));
			opacity_mult = map_mult;
		}
		
		// reflection glossiness map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_REFLECT_GLOSSINESS), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_REFLECT_GLOSSINESS), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			reflection_glossiness_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_REFLECT_GLOSSINESS));
			reflection_glossiness_texture_mult = map_mult;
		}

		// hilight glossiness map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_HILIGHT_GLOSSINESS), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_HILIGHT_GLOSSINESS), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			hilight_glossiness_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_HILIGHT_GLOSSINESS));
			hilight_glossiness_texture_mult = map_mult;
		}

		// anisotropy map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_ANISO), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_ANISO), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			anisotropy_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_ANISO));
			anisotropy_texture_mult = map_mult;
		}

		// anisotropy rotation map
		map_on = pblockMaps->GetInt(VRAYMTL_TEXMAP_ON_PARAMID(SUBTEXNO_ANISO_ROTATION), t);
		map_mult = pblockMaps->GetFloat(VRAYMTL_TEXMAP_MULT_PARAMID(SUBTEXNO_ANISO_ROTATION), t)/100.0f;
		if (map_on && map_mult > 0.0)
		{
			anisotropy_rotation_texture = pblockMaps->GetTexmap(VRAYMTL_TEXMAP_PARAMID(SUBTEXNO_ANISO_ROTATION));
			anisotropy_rotation_texture_mult = map_mult;
		}

		// .....
		// Other maps ( to total of 16 )
	}

	if (!refraction_trace)
	{
		refraction_texture = NULL;
		refraction_color = VUtils::Color(0, 0, 0);
	}

	// exportTextures:
	if(diffuse_texture)
		diffuse_texture_plugin = exportTexture(t, diffuse_texture, flags);

	if(bump_texture)
		bump_texture_plugin = exportTexture(t, bump_texture, flags);

	if(reflection_texture)
		reflection_texture_plugin = exportTexture(t, reflection_texture, flags);

	if(refraction_texture)
		refraction_texture_plugin = exportTexture(t, refraction_texture, flags);

	if(opacity_texture) {
		ExportFlags opacFlags=flags;
		opacFlags.texMonoOutput=1;
		opacity_texture_plugin = exportInvertedTexture(t, opacity_texture, opacFlags);
	}

	if(reflection_glossiness_texture)
		reflection_glossiness_texture_plugin = exportTextureAsFloat(t, reflection_glossiness_texture, flags);

	if(hilight_glossiness_texture)
		hilight_glossiness_texture_plugin = exportTextureAsFloat(t, hilight_glossiness_texture, flags);

	if (anisotropy_texture)
		anisotropy_texture_plugin=exportTextureAsFloat(t, anisotropy_texture, flags);

	if (anisotropy_rotation_texture)
		anisotropy_rotation_texture_plugin=exportTextureAsFloat(t, anisotropy_rotation_texture, flags);
	// end exportTextures

	....
}
